@@ -342,34 +342,37 @@ Heizoelrueckstossabdaempfung.
     }
 
     #[rstest]
-    #[case(
+    #[case::files_inplace_python(
         "files-inplace-python",
         "tests/files/files-python/in",
         &[
+            "-vvvv", // Trigger logging lines, just for more coverage
             "--sorted",
             "--glob",
             "**/*.py",
             "foo",
             "baz"
         ],
-        false
+        false,
     )]
-    #[case(
+    #[case::language_scoping_inplace_python(
         "language-scoping-inplace-python",
         "tests/files/language-scoping-python/in",
         &[
+            "-vvvv", // Trigger logging lines, just for more coverage
             "--sorted",
             "--python",
             "function-names",
             "foo",
             "baz"
         ],
-        false
+        false,
     )]
-    #[case(
+    #[case::language_scoping_and_files_inplace_python(
         "language-scoping-and-files-inplace-python",
         "tests/files/language-scoping-and-files-python/in",
         &[
+            "-vvvv", // Trigger logging lines, just for more coverage
             "--sorted",
             "--python",
             "function-names",
@@ -378,12 +381,13 @@ Heizoelrueckstossabdaempfung.
             "foo",
             "baz"
         ],
-        false
+        false,
     )]
-    #[case(
+    #[case::language_scoping_and_files_inplace_python(
         "language-scoping-and-files-inplace-python",
         "tests/files/language-scoping-and-files-python/in",
         &[
+            "-vvvv", // Trigger logging lines, just for more coverage
             "--python",
             "function-names",
             "--glob", // Will override language scoper
@@ -394,38 +398,72 @@ Heizoelrueckstossabdaempfung.
         // NOT `--sorted`, so not deterministic; use to test that directories are
         // equivalent even if running parallel, unsorted. Output will be random,
         // breaking snapshot testing.
-        true
+        true,
+    )]
+    #[case::binary_data_sorted(
+        "binary-data-sorted",
+        "tests/files/binary-data/in",
+        &[
+            "-vvvv", // Trigger logging lines, just for more coverage
+            "--sorted",
+            "--glob",
+            "**/*",
+            "0a1a09c8-2995-4ac5-9d60-01a0f02920e8",
+            "gone"
+        ],
+        false,
+    )]
+    #[case::binary_data_unsorted(
+        "binary-data-sorted",
+        "tests/files/binary-data/in",
+        &[
+            "-vvvv", // Trigger logging lines, just for more coverage
+            "--glob",
+            "**/*",
+            "0a1a09c8-2995-4ac5-9d60-01a0f02920e8",
+            "gone"
+        ],
+        // NOT `--sorted`, so not deterministic; use to test that directories are
+        // equivalent even if running parallel, unsorted. Output will be random,
+        // breaking snapshot testing.
+        true,
     )]
     fn test_cli_files(
         #[case] mut snapshot_name: String,
         #[case] input: PathBuf,
         #[case] args: &[&str],
         #[case] skip_output_check: bool,
+        #[values(true, false)] dry_run: bool, // Check all permutations for all inputs
     ) -> anyhow::Result<()> {
-        use std::mem::ManuallyDrop;
-
         let args = args.iter().map(ToString::to_string).collect_vec();
 
         // Arrange
         let mut cmd = get_cmd();
 
-        let baseline = {
+        let baseline = if dry_run {
+            // Stays the same! In dry runs, we compare against the very same directory,
+            // as it should not change.
+            input.clone()
+        } else {
             let mut baseline = input.clone();
             baseline.pop();
             baseline.push("out");
             baseline
         };
 
-        let candidate = ManuallyDrop::new(copy_to_tmp(&input));
+        let candidate = copy_to_tmp(&input);
         drop(input); // Prevent misuse
 
-        cmd.current_dir(&*candidate);
+        cmd.current_dir(&candidate);
         cmd.args(
             // Override; `Command` is detected as providing stdin but we're working on
             // files here.
             ["--stdin-override-to", "false"],
         );
         cmd.args(&args);
+        if dry_run {
+            cmd.arg("--dry-run");
+        }
 
         // Act
         let output = cmd.output().expect("failed to execute binary under test");
@@ -433,17 +471,27 @@ Heizoelrueckstossabdaempfung.
         // Assert
 
         // Thing itself works
-        assert!(output.status.success(), "Binary execution itself failed");
+        output.status.success().then_some(()).ok_or_else(|| {
+            anyhow::anyhow!(
+                "Binary execution itself failed: {}",
+                String::from_utf8_lossy(&output.stderr).escape_debug()
+            )
+        })?;
 
-        // Results are correct Do not drop on panic, to keep tmpdir in place for manual
-        // inspection. Can then diff directories.
+        // Do not drop on panic, to keep tmpdir in place for manual inspection. Can then
+        // diff directories.
         check_directories_equality(baseline, candidate.path().to_owned())?;
 
-        // Test was successful: ok to drop.
-        drop(ManuallyDrop::into_inner(candidate));
+        // Test was successful: ok to drop. Caveat: fails test if deletion fails, which
+        // is unwarranted coupling?
+        candidate.close()?;
 
         // Let's look at command output now.
         if !skip_output_check {
+            if dry_run {
+                snapshot_name.push_str("-dry-run");
+            }
+
             // These are inherently platform-specific, as they deal with file paths.
             snapshot_name.push('-');
             snapshot_name.push_str(std::env::consts::OS);
@@ -957,6 +1005,7 @@ right contents:
 
         let tmp_dir = tempfile::Builder::new()
             .prefix(pkg)
+            .keep(true) // Keep for manual inspection if needed
             .tempdir()
             .expect("Failed to create temporary directory");
 
