@@ -2,14 +2,7 @@ use std::ops::Range;
 
 use rstest::rstest;
 use serde::{Deserialize, Serialize};
-use srgn::scoping::langs::c::{PreparedCQuery, C};
-use srgn::scoping::langs::csharp::{CSharp, PreparedCSharpQuery};
-use srgn::scoping::langs::go::{Go, PreparedGoQuery};
-use srgn::scoping::langs::hcl::{Hcl, PreparedHclQuery};
-use srgn::scoping::langs::python::{PreparedPythonQuery, Python};
-use srgn::scoping::langs::rust::{PreparedRustQuery, Rust};
-use srgn::scoping::langs::typescript::{PreparedTypeScriptQuery, TypeScript};
-use srgn::scoping::langs::{CodeQuery, LanguageScoper};
+use srgn::scoping::langs::{c, csharp, go, hcl, python, rust, typescript, LanguageScoper};
 use srgn::scoping::scope::Scope;
 use srgn::scoping::view::ScopedViewBuilder;
 
@@ -73,757 +66,757 @@ impl InScopeLinePart {
 #[case(
     "base.py_comments",
     include_str!("python/base.py"),
-    Python::new(CodeQuery::Prepared(PreparedPythonQuery::Comments)),
+    python::CompiledQuery::from(python::PreparedQuery::Comments),
 )]
 #[case(
     "base.py_strings",
     include_str!("python/base.py"),
-    Python::new(CodeQuery::Prepared(PreparedPythonQuery::Strings)),
+    python::CompiledQuery::from(python::PreparedQuery::Strings),
 )]
 #[case(
     "base.py_imports",
     include_str!("python/base.py"),
-    Python::new(CodeQuery::Prepared(PreparedPythonQuery::Imports)),
+    python::CompiledQuery::from(python::PreparedQuery::Imports),
 )]
 #[case(
     "base.py_docstrings",
     include_str!("python/base.py"),
-    Python::new(CodeQuery::Prepared(PreparedPythonQuery::DocStrings)),
+    python::CompiledQuery::from(python::PreparedQuery::DocStrings),
 )]
 #[case(
     "base.py_function-names",
     include_str!("python/base.py"),
-    Python::new(CodeQuery::Prepared(PreparedPythonQuery::FunctionNames)),
+    python::CompiledQuery::from(python::PreparedQuery::FunctionNames),
 )]
 #[case(
     "base.py_function-calls",
     include_str!("python/base.py"),
-    Python::new(CodeQuery::Prepared(PreparedPythonQuery::FunctionCalls)),
+    python::CompiledQuery::from(python::PreparedQuery::FunctionCalls),
 )]
 #[case(
     "base.py_class",
     include_str!("python/base.py"),
-    Python::new(CodeQuery::Prepared(PreparedPythonQuery::Class)),
+    python::CompiledQuery::from(python::PreparedQuery::Class),
 )]
 #[case(
     "base.py_def",
     include_str!("python/base.py"),
-    Python::new(CodeQuery::Prepared(PreparedPythonQuery::Def)),
+    python::CompiledQuery::from(python::PreparedQuery::Def),
 )]
 #[case(
     "base.py_async-def",
     include_str!("python/base.py"),
-    Python::new(CodeQuery::Prepared(PreparedPythonQuery::AsyncDef)),
+    python::CompiledQuery::from(python::PreparedQuery::AsyncDef),
 )]
 #[case(
     "base.py_methods",
     include_str!("python/base.py"),
-    Python::new(CodeQuery::Prepared(PreparedPythonQuery::Methods)),
+    python::CompiledQuery::from(python::PreparedQuery::Methods),
 )]
 #[case(
     "base.py_classmethods",
     include_str!("python/base.py"),
-    Python::new(CodeQuery::Prepared(PreparedPythonQuery::ClassMethods)),
+    python::CompiledQuery::from(python::PreparedQuery::ClassMethods),
 )]
 #[case(
     "base.py_staticmethods",
     include_str!("python/base.py"),
-    Python::new(CodeQuery::Prepared(PreparedPythonQuery::StaticMethods)),
+    python::CompiledQuery::from(python::PreparedQuery::StaticMethods),
 )]
 #[case(
     "base.py_with",
     include_str!("python/base.py"),
-    Python::new(CodeQuery::Prepared(PreparedPythonQuery::With)),
+    python::CompiledQuery::from(python::PreparedQuery::With),
 )]
 #[case(
     "base.py_try",
     include_str!("python/base.py"),
-    Python::new(CodeQuery::Prepared(PreparedPythonQuery::Try)),
+    python::CompiledQuery::from(python::PreparedQuery::Try),
 )]
 #[case(
     "base.py_lambda",
     include_str!("python/base.py"),
-    Python::new(CodeQuery::Prepared(PreparedPythonQuery::Lambda)),
+    python::CompiledQuery::from(python::PreparedQuery::Lambda),
 )]
 #[case(
     "base.py_globals",
     include_str!("python/base.py"),
-    Python::new(CodeQuery::Prepared(PreparedPythonQuery::Globals)),
+    python::CompiledQuery::from(python::PreparedQuery::Globals),
 )]
 #[case(
     "base.py_variable_identifiers",
     include_str!("python/base.py"),
-    Python::new(CodeQuery::Prepared(PreparedPythonQuery::VariableIdentifiers)),
+    python::CompiledQuery::from(python::PreparedQuery::VariableIdentifiers),
 )]
 #[case(
     "base.py_types",
     include_str!("python/base.py"),
-    Python::new(CodeQuery::Prepared(PreparedPythonQuery::Types)),
+    python::CompiledQuery::from(python::PreparedQuery::Types),
 )]
 #[case(
     "base.py_identifiers",
     include_str!("python/base.py"),
-    Python::new(CodeQuery::Prepared(PreparedPythonQuery::Identifiers)),
+    python::CompiledQuery::from(python::PreparedQuery::Identifiers),
 )]
 #[case(
     "identifiers.py_identifiers",
     include_str!("python/identifiers.py"),
-    Python::new(CodeQuery::Prepared(PreparedPythonQuery::Identifiers)),
+    python::CompiledQuery::from(python::PreparedQuery::Identifiers),
 )]
 #[case(
     "base.ts_strings",
     include_str!("typescript/base.ts"),
-    TypeScript::new(CodeQuery::Prepared(PreparedTypeScriptQuery::Strings)),
+    typescript::CompiledQuery::from(typescript::PreparedQuery::Strings),
 )]
 #[case(
     "base.ts_comments",
     include_str!("typescript/base.ts"),
-    TypeScript::new(CodeQuery::Prepared(PreparedTypeScriptQuery::Comments)),
+    typescript::CompiledQuery::from(typescript::PreparedQuery::Comments),
 )]
 #[case(
     "base.ts_imports",
     include_str!("typescript/base.ts"),
-    TypeScript::new(CodeQuery::Prepared(PreparedTypeScriptQuery::Imports)),
+    typescript::CompiledQuery::from(typescript::PreparedQuery::Imports),
 )]
 #[case(
     "base.ts_function",
     include_str!("typescript/base.ts"),
-    TypeScript::new(CodeQuery::Prepared(PreparedTypeScriptQuery::Function)),
+    typescript::CompiledQuery::from(typescript::PreparedQuery::Function),
 )]
 #[case(
     "base.ts_async-function",
     include_str!("typescript/base.ts"),
-    TypeScript::new(CodeQuery::Prepared(PreparedTypeScriptQuery::AsyncFunction)),
+    typescript::CompiledQuery::from(typescript::PreparedQuery::AsyncFunction),
 )]
 #[case(
     "base.ts_sync-function",
     include_str!("typescript/base.ts"),
-    TypeScript::new(CodeQuery::Prepared(PreparedTypeScriptQuery::SyncFunction)),
+    typescript::CompiledQuery::from(typescript::PreparedQuery::SyncFunction),
 )]
 #[case(
     "base.ts_method",
     include_str!("typescript/base.ts"),
-    TypeScript::new(CodeQuery::Prepared(PreparedTypeScriptQuery::Method)),
+    typescript::CompiledQuery::from(typescript::PreparedQuery::Method),
 )]
 #[case(
     "base.ts_constructor",
     include_str!("typescript/base.ts"),
-    TypeScript::new(CodeQuery::Prepared(PreparedTypeScriptQuery::Constructor)),
+    typescript::CompiledQuery::from(typescript::PreparedQuery::Constructor),
 )]
 #[case(
     "base.ts_class",
     include_str!("typescript/base.ts"),
-    TypeScript::new(CodeQuery::Prepared(PreparedTypeScriptQuery::Class)),
+    typescript::CompiledQuery::from(typescript::PreparedQuery::Class),
 )]
 #[case(
     "base.ts_enum",
     include_str!("typescript/base.ts"),
-    TypeScript::new(CodeQuery::Prepared(PreparedTypeScriptQuery::Enum)),
+    typescript::CompiledQuery::from(typescript::PreparedQuery::Enum),
 )]
 #[case(
     "base.ts_interface",
     include_str!("typescript/base.ts"),
-    TypeScript::new(CodeQuery::Prepared(PreparedTypeScriptQuery::Interface)),
+    typescript::CompiledQuery::from(typescript::PreparedQuery::Interface),
 )]
 #[case(
     "base.ts_try-block",
     include_str!("typescript/base.ts"),
-    TypeScript::new(CodeQuery::Prepared(PreparedTypeScriptQuery::TryCatch)),
+    typescript::CompiledQuery::from(typescript::PreparedQuery::TryCatch),
 )]
 #[case(
     "base.ts_var_decl",
     include_str!("typescript/base.ts"),
-    TypeScript::new(CodeQuery::Prepared(PreparedTypeScriptQuery::VarDecl)),
+    typescript::CompiledQuery::from(typescript::PreparedQuery::VarDecl),
 )]
 #[case(
     "base.ts_let",
     include_str!("typescript/base.ts"),
-    TypeScript::new(CodeQuery::Prepared(PreparedTypeScriptQuery::Let)),
+    typescript::CompiledQuery::from(typescript::PreparedQuery::Let),
 )]
 #[case(
     "base.ts_const",
     include_str!("typescript/base.ts"),
-    TypeScript::new(CodeQuery::Prepared(PreparedTypeScriptQuery::Const)),
+    typescript::CompiledQuery::from(typescript::PreparedQuery::Const),
 )]
 #[case(
     "base.ts_var",
     include_str!("typescript/base.ts"),
-    TypeScript::new(CodeQuery::Prepared(PreparedTypeScriptQuery::Var)),
+    typescript::CompiledQuery::from(typescript::PreparedQuery::Var),
 )]
 #[case(
     "base.ts_type-params",
     include_str!("typescript/base.ts"),
-    TypeScript::new(CodeQuery::Prepared(PreparedTypeScriptQuery::TypeParams)),
+    typescript::CompiledQuery::from(typescript::PreparedQuery::TypeParams),
 )]
 #[case(
     "base.ts_type-alias",
     include_str!("typescript/base.ts"),
-    TypeScript::new(CodeQuery::Prepared(PreparedTypeScriptQuery::TypeAlias)),
+    typescript::CompiledQuery::from(typescript::PreparedQuery::TypeAlias),
 )]
 #[case(
     "base.ts_namespace",
     include_str!("typescript/base.ts"),
-    TypeScript::new(CodeQuery::Prepared(PreparedTypeScriptQuery::Namespace)),
+    typescript::CompiledQuery::from(typescript::PreparedQuery::Namespace),
 )]
 #[case(
     "base.ts_export",
     include_str!("typescript/base.ts"),
-    TypeScript::new(CodeQuery::Prepared(PreparedTypeScriptQuery::Export)),
+    typescript::CompiledQuery::from(typescript::PreparedQuery::Export),
 )]
 #[case(
     "base.rs_strings",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::Strings)),
+    rust::CompiledQuery::from(rust::PreparedQuery::Strings),
 )]
 #[case(
     "base.rs_comments",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::Comments)),
+    rust::CompiledQuery::from(rust::PreparedQuery::Comments),
 )]
 #[case(
     "base.rs_uses",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::Uses)),
+    rust::CompiledQuery::from(rust::PreparedQuery::Uses),
 )]
 #[case(
     "base.rs_doc-comments",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::DocComments)),
+    rust::CompiledQuery::from(rust::PreparedQuery::DocComments),
 )]
 #[case(
     "base.rs_attribute",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::Attribute)),
+    rust::CompiledQuery::from(rust::PreparedQuery::Attribute),
 )]
 #[case(
     "base.rs_struct",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::Struct)),
+    rust::CompiledQuery::from(rust::PreparedQuery::Struct),
 )]
 #[case(
     "base.rs_pub-struct",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::PubStruct)),
+    rust::CompiledQuery::from(rust::PreparedQuery::PubStruct),
 )]
 #[case(
     "base.rs_pub-priv-struct",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::PrivStruct)),
+    rust::CompiledQuery::from(rust::PreparedQuery::PrivStruct),
 )]
 #[case(
     "base.rs_pub-crate-struct",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::PubCrateStruct)),
+    rust::CompiledQuery::from(rust::PreparedQuery::PubCrateStruct),
 )]
 #[case(
     "base.rs_pub-self-struct",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::PubSelfStruct)),
+    rust::CompiledQuery::from(rust::PreparedQuery::PubSelfStruct),
 )]
 #[case(
     "base.rs_pub-super-struct",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::PubSuperStruct)),
+    rust::CompiledQuery::from(rust::PreparedQuery::PubSuperStruct),
 )]
 #[case(
     "base.enum",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::Enum)),
+    rust::CompiledQuery::from(rust::PreparedQuery::Enum),
 )]
 #[case(
     "base.rs_pub-priv-enum",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::PrivEnum)),
+    rust::CompiledQuery::from(rust::PreparedQuery::PrivEnum),
 )]
 #[case(
     "base.rs_pub-enum",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::PubEnum)),
+    rust::CompiledQuery::from(rust::PreparedQuery::PubEnum),
 )]
 #[case(
     "base.rs_pub-crate-enum",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::PubCrateEnum)),
+    rust::CompiledQuery::from(rust::PreparedQuery::PubCrateEnum),
 )]
 #[case(
     "base.rs_pub-self-enum",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::PubSelfEnum)),
+    rust::CompiledQuery::from(rust::PreparedQuery::PubSelfEnum),
 )]
 #[case(
     "base.rs_pub-super-enum",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::PubSuperEnum)),
+    rust::CompiledQuery::from(rust::PreparedQuery::PubSuperEnum),
 )]
 #[case(
     "base.rs_enum-variant",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::EnumVariant)),
+    rust::CompiledQuery::from(rust::PreparedQuery::EnumVariant),
 )]
 #[case(
     "base.rs_fn",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::Fn)),
+    rust::CompiledQuery::from(rust::PreparedQuery::Fn),
 )]
 #[case(
     "base.rs_impl-fn",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::ImplFn)),
+    rust::CompiledQuery::from(rust::PreparedQuery::ImplFn),
 )]
 #[case(
     "base.rs_pub-priv-fn",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::PrivFn)),
+    rust::CompiledQuery::from(rust::PreparedQuery::PrivFn),
 )]
 #[case(
     "base.rs_pub-fn",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::PubFn)),
+    rust::CompiledQuery::from(rust::PreparedQuery::PubFn),
 )]
 #[case(
     "base.rs_pub-crate-fn",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::PubCrateFn)),
+    rust::CompiledQuery::from(rust::PreparedQuery::PubCrateFn),
 )]
 #[case(
     "base.rs_pub-self-fn",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::PubSelfFn)),
+    rust::CompiledQuery::from(rust::PreparedQuery::PubSelfFn),
 )]
 #[case(
     "base.rs_pub-super-fn",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::PubSuperFn)),
+    rust::CompiledQuery::from(rust::PreparedQuery::PubSuperFn),
 )]
 #[case(
     "base.rs_const-fn",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::ConstFn)),
+    rust::CompiledQuery::from(rust::PreparedQuery::ConstFn),
 )]
 #[case(
     "base.rs_async-fn",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::AsyncFn)),
+    rust::CompiledQuery::from(rust::PreparedQuery::AsyncFn),
 )]
 #[case(
     "base.rs_unsafe-fn",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::UnsafeFn)),
+    rust::CompiledQuery::from(rust::PreparedQuery::UnsafeFn),
 )]
 #[case(
     "base.rs_extern-fn",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::ExternFn)),
+    rust::CompiledQuery::from(rust::PreparedQuery::ExternFn),
 )]
 #[case(
     "base.rs_test-fn",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::TestFn)),
+    rust::CompiledQuery::from(rust::PreparedQuery::TestFn),
 )]
 #[case(
     "base.rs_trait",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::Trait)),
+    rust::CompiledQuery::from(rust::PreparedQuery::Trait),
 )]
 #[case(
     "base.rs_impl",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::Impl)),
+    rust::CompiledQuery::from(rust::PreparedQuery::Impl),
 )]
 #[case(
     "base.rs_impl-trait",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::ImplTrait)),
+    rust::CompiledQuery::from(rust::PreparedQuery::ImplTrait),
 )]
 #[case(
     "base.rs_impl-type",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::ImplType)),
+    rust::CompiledQuery::from(rust::PreparedQuery::ImplType),
 )]
 #[case(
     "base.rs_mod",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::Mod)),
+    rust::CompiledQuery::from(rust::PreparedQuery::Mod),
 )]
 #[case(
     "base.rs_mod-tests",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::ModTests)),
+    rust::CompiledQuery::from(rust::PreparedQuery::ModTests),
 )]
 #[case(
     "base.rs_typedefs",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::TypeDef)),
+    rust::CompiledQuery::from(rust::PreparedQuery::TypeDef),
 )]
 #[case(
     "base.rs_identifier",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::Identifier)),
+    rust::CompiledQuery::from(rust::PreparedQuery::Identifier),
 )]
 #[case(
     "base.rs_type-identifier",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::TypeIdentifier)),
+    rust::CompiledQuery::from(rust::PreparedQuery::TypeIdentifier),
 )]
 #[case(
     "base.rs_closure",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::Closure)),
+    rust::CompiledQuery::from(rust::PreparedQuery::Closure),
 )]
 #[case(
     "base.rs_unsafe",
     include_str!("rust/base.rs"),
-    Rust::new(CodeQuery::Prepared(PreparedRustQuery::Unsafe)),
+    rust::CompiledQuery::from(rust::PreparedQuery::Unsafe),
 )]
 #[case(
     "base.tf_variable-block",
     include_str!("hcl/base.tf"),
-    Hcl::new(CodeQuery::Prepared(PreparedHclQuery::Variable)),
+    hcl::CompiledQuery::from(hcl::PreparedQuery::Variable),
 )]
 #[case(
     "base.tf_resource-block",
     include_str!("hcl/base.tf"),
-    Hcl::new(CodeQuery::Prepared(PreparedHclQuery::Resource)),
+    hcl::CompiledQuery::from(hcl::PreparedQuery::Resource),
 )]
 #[case(
     "base.tf_data-block",
     include_str!("hcl/base.tf"),
-    Hcl::new(CodeQuery::Prepared(PreparedHclQuery::Data)),
+    hcl::CompiledQuery::from(hcl::PreparedQuery::Data),
 )]
 #[case(
     "base.tf_output-block",
     include_str!("hcl/base.tf"),
-    Hcl::new(CodeQuery::Prepared(PreparedHclQuery::Output)),
+    hcl::CompiledQuery::from(hcl::PreparedQuery::Output),
 )]
 #[case(
     "base.tf_provider-block",
     include_str!("hcl/base.tf"),
-    Hcl::new(CodeQuery::Prepared(PreparedHclQuery::Provider)),
+    hcl::CompiledQuery::from(hcl::PreparedQuery::Provider),
 )]
 #[case(
     "base.tf_terraform-block",
     include_str!("hcl/base.tf"),
-    Hcl::new(CodeQuery::Prepared(PreparedHclQuery::Terraform)),
+    hcl::CompiledQuery::from(hcl::PreparedQuery::Terraform),
 )]
 #[case(
     "base.tf_locals-block",
     include_str!("hcl/base.tf"),
-    Hcl::new(CodeQuery::Prepared(PreparedHclQuery::Locals)),
+    hcl::CompiledQuery::from(hcl::PreparedQuery::Locals),
 )]
 #[case(
     "base.tf_module-block",
     include_str!("hcl/base.tf"),
-    Hcl::new(CodeQuery::Prepared(PreparedHclQuery::Module)),
+    hcl::CompiledQuery::from(hcl::PreparedQuery::Module),
 )]
 #[case(
     "base.tf_variables",
     include_str!("hcl/base.tf"),
-    Hcl::new(CodeQuery::Prepared(PreparedHclQuery::Variables)),
+    hcl::CompiledQuery::from(hcl::PreparedQuery::Variables),
 )]
 #[case(
     "base.tf_resource-types",
     include_str!("hcl/base.tf"),
-    Hcl::new(CodeQuery::Prepared(PreparedHclQuery::ResourceTypes)),
+    hcl::CompiledQuery::from(hcl::PreparedQuery::ResourceTypes),
 )]
 #[case(
     "base.tf_resource-names",
     include_str!("hcl/base.tf"),
-    Hcl::new(CodeQuery::Prepared(PreparedHclQuery::ResourceNames)),
+    hcl::CompiledQuery::from(hcl::PreparedQuery::ResourceNames),
 )]
 #[case(
     "base.tf_data-names",
     include_str!("hcl/base.tf"),
-    Hcl::new(CodeQuery::Prepared(PreparedHclQuery::DataNames)),
+    hcl::CompiledQuery::from(hcl::PreparedQuery::DataNames),
 )]
 #[case(
     "base.tf_data-sources",
     include_str!("hcl/base.tf"),
-    Hcl::new(CodeQuery::Prepared(PreparedHclQuery::DataSources)),
+    hcl::CompiledQuery::from(hcl::PreparedQuery::DataSources),
 )]
 #[case(
     "base.tf_comments",
     include_str!("hcl/base.tf"),
-    Hcl::new(CodeQuery::Prepared(PreparedHclQuery::Comments)),
+    hcl::CompiledQuery::from(hcl::PreparedQuery::Comments),
 )]
 #[case(
     "base.tf_strings",
     include_str!("hcl/base.tf"),
-    Hcl::new(CodeQuery::Prepared(PreparedHclQuery::Strings)),
+    hcl::CompiledQuery::from(hcl::PreparedQuery::Strings),
 )]
 #[case(
     "base.go_comments",
     include_str!("go/base.go"),
-    Go::new(CodeQuery::Prepared(PreparedGoQuery::Comments)),
+    go::CompiledQuery::from(go::PreparedQuery::Comments),
 )]
 #[case(
     "base.go_strings",
     include_str!("go/base.go"),
-    Go::new(CodeQuery::Prepared(PreparedGoQuery::Strings)),
+    go::CompiledQuery::from(go::PreparedQuery::Strings),
 )]
 #[case(
     "base.go_imports",
     include_str!("go/base.go"),
-    Go::new(CodeQuery::Prepared(PreparedGoQuery::Imports)),
+    go::CompiledQuery::from(go::PreparedQuery::Imports),
 )]
 #[case(
     "base.go_type-def",
     include_str!("go/base.go"),
-    Go::new(CodeQuery::Prepared(PreparedGoQuery::TypeDef)),
+    go::CompiledQuery::from(go::PreparedQuery::TypeDef),
 )]
 #[case(
     "base.go_type-alias",
     include_str!("go/base.go"),
-    Go::new(CodeQuery::Prepared(PreparedGoQuery::TypeAlias)),
+    go::CompiledQuery::from(go::PreparedQuery::TypeAlias),
 )]
 #[case(
     "base.go_struct",
     include_str!("go/base.go"),
-    Go::new(CodeQuery::Prepared(PreparedGoQuery::Struct)),
+    go::CompiledQuery::from(go::PreparedQuery::Struct),
 )]
 #[case(
     "base.go_interface",
     include_str!("go/base.go"),
-    Go::new(CodeQuery::Prepared(PreparedGoQuery::Interface)),
+    go::CompiledQuery::from(go::PreparedQuery::Interface),
 )]
 #[case(
     "base.go_const",
     include_str!("go/base.go"),
-    Go::new(CodeQuery::Prepared(PreparedGoQuery::Const)),
+    go::CompiledQuery::from(go::PreparedQuery::Const),
 )]
 #[case(
     "base.go_var",
     include_str!("go/base.go"),
-    Go::new(CodeQuery::Prepared(PreparedGoQuery::Var)),
+    go::CompiledQuery::from(go::PreparedQuery::Var),
 )]
 #[case(
     "base.go_func",
     include_str!("go/base.go"),
-    Go::new(CodeQuery::Prepared(PreparedGoQuery::Func)),
+    go::CompiledQuery::from(go::PreparedQuery::Func),
 )]
 #[case(
     "base.go_method",
     include_str!("go/base.go"),
-    Go::new(CodeQuery::Prepared(PreparedGoQuery::Method)),
+    go::CompiledQuery::from(go::PreparedQuery::Method),
 )]
 #[case(
     "base.go_free-func",
     include_str!("go/base.go"),
-    Go::new(CodeQuery::Prepared(PreparedGoQuery::FreeFunc)),
+    go::CompiledQuery::from(go::PreparedQuery::FreeFunc),
 )]
 #[case(
     "base.go_init-func",
     include_str!("go/base.go"),
-    Go::new(CodeQuery::Prepared(PreparedGoQuery::InitFunc)),
+    go::CompiledQuery::from(go::PreparedQuery::InitFunc),
 )]
 #[case(
     "base.go_type-params",
     include_str!("go/base.go"),
-    Go::new(CodeQuery::Prepared(PreparedGoQuery::TypeParams)),
+    go::CompiledQuery::from(go::PreparedQuery::TypeParams),
 )]
 #[case(
     "base.go_defer",
     include_str!("go/base.go"),
-    Go::new(CodeQuery::Prepared(PreparedGoQuery::Defer)),
+    go::CompiledQuery::from(go::PreparedQuery::Defer),
 )]
 #[case(
     "base.go_select",
     include_str!("go/base.go"),
-    Go::new(CodeQuery::Prepared(PreparedGoQuery::Select)),
+    go::CompiledQuery::from(go::PreparedQuery::Select),
 )]
 #[case(
     "base.go_go",
     include_str!("go/base.go"),
-    Go::new(CodeQuery::Prepared(PreparedGoQuery::Go)),
+    go::CompiledQuery::from(go::PreparedQuery::Go),
 )]
 #[case(
     "base.go_switch",
     include_str!("go/base.go"),
-    Go::new(CodeQuery::Prepared(PreparedGoQuery::Switch)),
+    go::CompiledQuery::from(go::PreparedQuery::Switch),
 )]
 #[case(
     "base.go_labeled",
     include_str!("go/base.go"),
-    Go::new(CodeQuery::Prepared(PreparedGoQuery::Labeled)),
+    go::CompiledQuery::from(go::PreparedQuery::Labeled),
 )]
 #[case(
     "base.go_goto",
     include_str!("go/base.go"),
-    Go::new(CodeQuery::Prepared(PreparedGoQuery::Goto)),
+    go::CompiledQuery::from(go::PreparedQuery::Goto),
 )]
 #[case(
     "base.go_struct-tags",
     include_str!("go/base.go"),
-    Go::new(CodeQuery::Prepared(PreparedGoQuery::StructTags)),
+    go::CompiledQuery::from(go::PreparedQuery::StructTags),
 )]
 #[case(
     "base.cs_strings",
     include_str!("csharp/base.cs"),
-    CSharp::new(CodeQuery::Prepared(PreparedCSharpQuery::Strings)),
+    csharp::CompiledQuery::from(csharp::PreparedQuery::Strings),
 )]
 #[case(
     "base.cs_usings",
     include_str!("csharp/base.cs"),
-    CSharp::new(CodeQuery::Prepared(PreparedCSharpQuery::Usings)),
+    csharp::CompiledQuery::from(csharp::PreparedQuery::Usings),
 )]
 #[case(
     "base.cs_comments",
     include_str!("csharp/base.cs"),
-    CSharp::new(CodeQuery::Prepared(PreparedCSharpQuery::Comments)),
+    csharp::CompiledQuery::from(csharp::PreparedQuery::Comments),
 )]
 #[case(
     "base.cs_struct",
     include_str!("csharp/base.cs"),
-    CSharp::new(CodeQuery::Prepared(PreparedCSharpQuery::Struct)),
+    csharp::CompiledQuery::from(csharp::PreparedQuery::Struct),
 )]
 #[case(
     "base.cs_enum",
     include_str!("csharp/base.cs"),
-    CSharp::new(CodeQuery::Prepared(PreparedCSharpQuery::Enum)),
+    csharp::CompiledQuery::from(csharp::PreparedQuery::Enum),
 )]
 #[case(
     "base.cs_field",
     include_str!("csharp/base.cs"),
-    CSharp::new(CodeQuery::Prepared(PreparedCSharpQuery::Field)),
+    csharp::CompiledQuery::from(csharp::PreparedQuery::Field),
 )]
 #[case(
     "base.cs_attribute",
     include_str!("csharp/base.cs"),
-    CSharp::new(CodeQuery::Prepared(PreparedCSharpQuery::Attribute)),
+    csharp::CompiledQuery::from(csharp::PreparedQuery::Attribute),
 )]
 #[case(
     "base.cs_interface",
     include_str!("csharp/base.cs"),
-    CSharp::new(CodeQuery::Prepared(PreparedCSharpQuery::Interface)),
+    csharp::CompiledQuery::from(csharp::PreparedQuery::Interface),
 )]
 #[case(
     "base.cs_class",
     include_str!("csharp/base.cs"),
-    CSharp::new(CodeQuery::Prepared(PreparedCSharpQuery::Class)),
+    csharp::CompiledQuery::from(csharp::PreparedQuery::Class),
 )]
 #[case(
     "base.cs_variable_declaration",
     include_str!("csharp/base.cs"),
-    CSharp::new(CodeQuery::Prepared(PreparedCSharpQuery::VariableDeclaration)),
+    csharp::CompiledQuery::from(csharp::PreparedQuery::VariableDeclaration),
 )]
 #[case(
     "base.cs_property",
     include_str!("csharp/base.cs"),
-    CSharp::new(CodeQuery::Prepared(PreparedCSharpQuery::Property)),
+    csharp::CompiledQuery::from(csharp::PreparedQuery::Property),
 )]
 #[case(
     "base.cs_constructor",
     include_str!("csharp/base.cs"),
-    CSharp::new(CodeQuery::Prepared(PreparedCSharpQuery::Constructor)),
+    csharp::CompiledQuery::from(csharp::PreparedQuery::Constructor),
 )]
 #[case(
     "base.cs_destructor",
     include_str!("csharp/base.cs"),
-    CSharp::new(CodeQuery::Prepared(PreparedCSharpQuery::Destructor)),
+    csharp::CompiledQuery::from(csharp::PreparedQuery::Destructor),
 )]
 #[case(
     "base.cs_method",
     include_str!("csharp/base.cs"),
-    CSharp::new(CodeQuery::Prepared(PreparedCSharpQuery::Method)),
+    csharp::CompiledQuery::from(csharp::PreparedQuery::Method),
 )]
 #[case(
     "base.cs_identifier",
     include_str!("csharp/base.cs"),
-    CSharp::new(CodeQuery::Prepared(PreparedCSharpQuery::Identifier)),
+    csharp::CompiledQuery::from(csharp::PreparedQuery::Identifier),
 )]
 #[case(
     "base.c_comments",
     include_str!("c/base.c"),
-    C::new(CodeQuery::Prepared(PreparedCQuery::Comments)),
+   c::CompiledQuery::from (c::PreparedQuery::Comments),
 )]
 #[case(
     "base.c_strings",
     include_str!("c/base.c"),
-    C::new(CodeQuery::Prepared(PreparedCQuery::Strings)),
+   c::CompiledQuery::from (c::PreparedQuery::Strings),
 )]
 #[case(
     "base.c_includes",
     include_str!("c/base.c"),
-    C::new(CodeQuery::Prepared(PreparedCQuery::Includes)),
+   c::CompiledQuery::from (c::PreparedQuery::Includes),
 )]
 #[case(
     "base.c_typedefs",
     include_str!("c/base.c"),
-    C::new(CodeQuery::Prepared(PreparedCQuery::TypeDef)),
+   c::CompiledQuery::from (c::PreparedQuery::TypeDef),
 )]
 #[case(
     "base.c_enum",
     include_str!("c/base.c"),
-    C::new(CodeQuery::Prepared(PreparedCQuery::Enum)),
+   c::CompiledQuery::from (c::PreparedQuery::Enum),
 )]
 #[case(
     "base.c_struct",
     include_str!("c/base.c"),
-    C::new(CodeQuery::Prepared(PreparedCQuery::Struct)),
+   c::CompiledQuery::from (c::PreparedQuery::Struct),
 )]
 #[case(
     "base.c_variable",
     include_str!("c/base.c"),
-    C::new(CodeQuery::Prepared(PreparedCQuery::Variable)),
+   c::CompiledQuery::from (c::PreparedQuery::Variable),
 )]
 #[case(
     "base.c_function",
     include_str!("c/base.c"),
-    C::new(CodeQuery::Prepared(PreparedCQuery::Function)),
+   c::CompiledQuery::from (c::PreparedQuery::Function),
 )]
 #[case(
     "base.c_function_definition",
     include_str!("c/base.c"),
-    C::new(CodeQuery::Prepared(PreparedCQuery::FunctionDef)),
+   c::CompiledQuery::from (c::PreparedQuery::FunctionDef),
 )]
 #[case(
     "base.c_function_declaration",
     include_str!("c/base.c"),
-    C::new(CodeQuery::Prepared(PreparedCQuery::FunctionDecl)),
+   c::CompiledQuery::from (c::PreparedQuery::FunctionDecl),
 )]
 #[case(
     "base.c_switch",
     include_str!("c/base.c"),
-    C::new(CodeQuery::Prepared(PreparedCQuery::Switch)),
+   c::CompiledQuery::from (c::PreparedQuery::Switch),
 )]
 #[case(
     "base.c_if",
     include_str!("c/base.c"),
-    C::new(CodeQuery::Prepared(PreparedCQuery::If)),
+   c::CompiledQuery::from (c::PreparedQuery::If),
 )]
 #[case(
     "base.c_for",
     include_str!("c/base.c"),
-    C::new(CodeQuery::Prepared(PreparedCQuery::For)),
+   c::CompiledQuery::from (c::PreparedQuery::For),
 )]
 #[case(
     "base.c_while",
     include_str!("c/base.c"),
-    C::new(CodeQuery::Prepared(PreparedCQuery::While)),
+   c::CompiledQuery::from (c::PreparedQuery::While),
 )]
 #[case(
     "base.c_do",
     include_str!("c/base.c"),
-    C::new(CodeQuery::Prepared(PreparedCQuery::Do)),
+   c::CompiledQuery::from (c::PreparedQuery::Do),
 )]
 #[case(
     "base.c_union",
     include_str!("c/base.c"),
-    C::new(CodeQuery::Prepared(PreparedCQuery::Union)),
+   c::CompiledQuery::from (c::PreparedQuery::Union),
 )]
 #[case(
     "base.c_identifier",
     include_str!("c/base.c"),
-    C::new(CodeQuery::Prepared(PreparedCQuery::Identifier)),
+   c::CompiledQuery::from (c::PreparedQuery::Identifier),
 )]
 #[case(
     "base.c_declaration",
     include_str!("c/base.c"),
-    C::new(CodeQuery::Prepared(PreparedCQuery::Declaration)),
+   c::CompiledQuery::from (c::PreparedQuery::Declaration),
 )]
 #[case(
     "base.c_callexpr",
     include_str!("c/base.c"),
-    C::new(CodeQuery::Prepared(PreparedCQuery::CallExpression)),
+   c::CompiledQuery::from (c::PreparedQuery::CallExpression),
 )]
 fn test_language_scopers(
     #[case] snapshot_name: &str,
