@@ -30,7 +30,7 @@ mod tests {
         alpha1 as ascii_alpha1, alphanumeric1 as ascii_alphanumeric1, anychar, char, line_ending,
         none_of, space0, space1,
     };
-    use nom::combinator::{cut, eof, map, opt};
+    use nom::combinator::{cut, eof, map, opt, recognize};
     use nom::error::ParseError;
     use nom::multi::{many0, many1, many_till, separated_list1};
     use nom::sequence::{delimited, preceded, tuple};
@@ -466,6 +466,7 @@ mod tests {
     }
 
     /// Parses a single, whole program invocation.
+    #[allow(clippy::too_many_lines)] // :( many hard-coded values
     fn parse_program(input: &str) -> IResult<&str, Program> {
         // Interior mutability is fine, as the different closures aliasing this run
         // sequentially, never at once (is using this and `map` of `nom` an
@@ -491,34 +492,58 @@ mod tests {
                             // *flag*, and `some_value` as a *positional argument*.
                             tag("--"),
                             alt((
-                                // Careful: all `--lang-query` options need to come
-                                // first; otherwise, the `--lang` options eat them and
-                                // results turn bad (complaining that `-query` is not a
-                                // valid value). Parsing is brittle here :-(
-                                tag("csharp-query"),
-                                tag("go-query"),
-                                tag("hcl-query"),
-                                tag("python-query"),
-                                tag("rust-query"),
-                                tag("typescript-query"),
+                                // ⚠️ Careful: all `--<lang>-query` options need to come
+                                // first; otherwise, the shorter `--<lang>` options eat
+                                // them and results turn bad (complaining that `-query`
+                                // is not a valid value). Generally, parsing is greedy,
+                                // so shorter values will short-circuit, potentially
+                                // incorrectly. That's why lines are generally sorted
+                                // longest to shortest, to avoid confusion.
+                                alt((
+                                    tag("typescript-query-file"),
+                                    tag("csharp-query-file"),
+                                    tag("python-query-file"),
+                                    tag("rust-query-file"),
+                                    tag("hcl-query-file"),
+                                    tag("go-query-file"),
+                                    tag("c-query-file"),
+                                )),
                                 //
-                                tag("csharp"),
-                                tag("glob"),
-                                tag("go"),
-                                tag("hcl"),
-                                tag("python"),
-                                tag("rust"),
-                                tag("stdin-override-to"),
-                                tag("threads"),
-                                tag("typescript"),
+                                // Parsing is brittle here :-(
+                                alt((
+                                    tag("typescript-query"),
+                                    tag("csharp-query"),
+                                    tag("python-query"),
+                                    tag("rust-query"),
+                                    tag("hcl-query"),
+                                    tag("go-query"),
+                                    tag("c-query"),
+                                )),
                                 //
-                                // Shorthands. NOTE: only a limited number of elements
-                                // can go here. `nom` is generic, and this tuple inside
-                                // `alt` is limited to 21 members.
-                                tag("cs"),
-                                tag("py"),
-                                tag("rs"),
-                                tag("ts"),
+                                alt((
+                                    tag("typescript"),
+                                    tag("csharp"),
+                                    tag("python"),
+                                    tag("rust"),
+                                    tag("hcl"),
+                                    tag("go"),
+                                    tag("c"),
+                                )),
+                                // Misc. flags used in the docs
+                                alt((tag("glob"), tag("stdin-override-to"), tag("threads"))),
+                                // Shorthands
+                                alt((
+                                    tag("tsx"),
+                                    tag("hcl"),
+                                    tag("cs"),
+                                    tag("py"),
+                                    tag("rs"),
+                                    tag("ts"),
+                                    tag("go"),
+                                    tag("tf"),
+                                    tag("c"),
+                                    // tag("h"), // Breaks `--help` and isn't used
+                                )),
                             )),
                         ),
                         cut(
@@ -529,7 +554,7 @@ mod tests {
                                 // Quoting always is technically overkill, but much
                                 // simpler and safer
                                 parse_quoted,
-                                space1,
+                                space0,
                             ),
                         ),
                     )),
@@ -582,16 +607,16 @@ mod tests {
                     },
                 ),
                 map(
-                    // There's also file names, which cannot occur quoted in shell
-                    // contexts
-                    tuple((ascii_alphanumeric1, char('.'), ascii_alphanumeric1)),
-                    |parts: (&str, char, &str)| {
-                        let (stem, sep, suffix) = parts;
-                        let file_name = format!("{stem}{sep}{suffix}");
+                    // File paths.
+                    recognize(tuple((
+                        many1(alt((ascii_alphanumeric1, tag("/"), tag("-"), tag("_")))),
+                        char('.'),
+                        ascii_alphanumeric1,
+                    ))),
+                    |file_path: &str| {
+                        inv.borrow_mut().args.push(file_path.into());
 
-                        inv.borrow_mut().args.push(file_name.as_str().into());
-
-                        file_name
+                        file_path.to_owned()
                     },
                 ),
             ))),
@@ -802,6 +827,8 @@ mod tests {
 
     #[test]
     fn test_readme_code_blocks() {
+        let _helper = TestHinter;
+
         let snippets = get_readme_snippets();
         let pipes = get_readme_program_pipes(&snippets);
 
@@ -933,4 +960,18 @@ mod tests {
 
         res
     }
+
+    struct TestHinter;
+
+    impl Drop for TestHinter {
+        fn drop(&mut self) {
+            if std::thread::panicking() {
+                println!("\n==============================================");
+                println!("💡 README test failed!");
+                println!("Did you update the `srgn --help` output?");
+                println!("If no, run `./scripts/update-readme.py README.md` and try again.");
+                println!("==============================================\n");
+            }
+        }
+    }
 }
